# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2008, Gustavo Narea <me@gustavonarea.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the BSD-like license at
# http://www.repoze.org/LICENSE.txt.  A copy of the license should accompany
# this distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND
# FITNESS FOR A PARTICULAR PURPOSE
#
##############################################################################

"""Stuff required to setup the test database."""

import os

from sqlalchemy import *
from sqlalchemy.orm import *
from cStringIO import StringIO
from cgi import FieldStorage
import elixir

from model import init_model, DBSession, metadata, Permission, Group, User

engine = create_engine(os.environ.get('DBURL', 'sqlite://'))

def setup_database():
    init_model(engine)
    teardownDatabase()
    elixir.setup_all(True)

    # Creating permissions

    see_site = Permission()
    see_site.permission_name = u'see-site'
    see_site.description = u'see-site permission description'
    DBSession.save(see_site)

    edit_site = Permission()
    edit_site.permission_name = u'edit-site'
    edit_site.description = u'edit-site permission description'
    DBSession.save(edit_site)

    commit = Permission()
    commit.permission_name = u'commit'
    commit.description = u'commit permission description'
    DBSession.save(commit)

    # Creating groups

    admins = Group()
    admins.group_name = u'admins'
    admins.display_name = u'Admins Group'
    admins.permissions.append(edit_site)
    DBSession.save(admins)

    developers = Group(group_name=u'developers',
                       display_name=u'Developers Group')
    developers.permissions = [commit, edit_site]
    DBSession.save(developers)

    trolls = Group(group_name=u'trolls', display_name=u'Trolls Group')
    trolls.permissions.append(see_site)
    DBSession.save(trolls)

    # Plus a couple of groups with no permissions
    php = Group(group_name=u'php', display_name=u'PHP Group')
    DBSession.save(php)

    python = Group(group_name=u'python', display_name=u'Python Group')
    DBSession.save(python)

    # Creating users

    user = User()
    user.user_name = u'rms'
    user.password = u'freedom'
    user.email_address = u'someone@fsf.ext'
    user.groups.append(admins)
    user.groups.append(developers)
    DBSession.save(user)

    user = User()
    user.user_name = u'linus'
    user.password = u'linux'
    user.email_address = u'someone@linux.ext'
    user.groups.append(developers)
    DBSession.save(user)

    user = User()
    user.user_name = u'sballmer'
    user.password = u'developers'
    user.email_address = u'developer@developers.dev'
    user.groups.append(trolls)
    DBSession.save(user)

    # Plus a couple of users without groups
    user = User()
    user.user_name = u'guido'
    user.password = u'phytonic'
    user.email_address = u'someone@python.ext'
    DBSession.save(user)

    user = User()
    user.user_name = u'rasmus'
    user.password = u'php'
    user.email_address = u'someone@php.ext'
    DBSession.save(user)

    DBSession.commit()


def teardownDatabase():
    DBSession.rollback()
    metadata.drop_all(engine)



# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2008, Gustavo Narea <me@gustavonarea.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the BSD-like license at
# http://www.repoze.org/LICENSE.txt.  A copy of the license should accompany
# this distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND
# FITNESS FOR A PARTICULAR PURPOSE
#
##############################################################################

"""Test suite for the SQL plugin."""

import unittest

from repoze.what.plugins.quickstart import SQLAuthenticatorPlugin
from repoze.what.plugins.sql import SqlGroupsAdapter, \
                                            SqlPermissionsAdapter, \
                                            configure_sql_adapters
from repoze.what.adapters.testutil import GroupsAdapterTester, \
                                                  PermissionsAdapterTester

import databasesetup
from model import User, Group, Permission, DBSession


class _BaseSqlAdapterTester(unittest.TestCase):
    """Base class for the test suite of the SQL source adapters"""
    
    def tearDown(self):
        databasesetup.teardownDatabase()


class TestSqlGroupsAdapter(GroupsAdapterTester, _BaseSqlAdapterTester):
    """Test suite for the SQL group source adapter"""
    
    def setUp(self):
        super(TestSqlGroupsAdapter, self).setUp()
        databasesetup.setup_database()
        self.adapter = SqlGroupsAdapter(databasesetup.Group,
                                        databasesetup.User,
                                        databasesetup.DBSession)


class TestSqlPermissionsAdapter(PermissionsAdapterTester,
                                _BaseSqlAdapterTester):
    """Test suite for the SQL permission source adapter"""
    
    def setUp(self):
        super(TestSqlPermissionsAdapter, self).setUp()
        databasesetup.setup_database()
        self.adapter = SqlPermissionsAdapter(databasesetup.Permission,
                                             databasesetup.Group,
                                             databasesetup.DBSession)


class TestAdaptersConfigurator(unittest.TestCase):
    """Tests for the L{configure_sql_adapters} utility"""
    
    def test_without_translations(self):
        adapters = configure_sql_adapters(User, Group, Permission, DBSession)
        group_adapter = adapters['group']
        permission_adapter = adapters['permission']
        assert isinstance(group_adapter, SqlGroupsAdapter)
        assert isinstance(permission_adapter, SqlPermissionsAdapter)
        self.assertEquals(DBSession, group_adapter.dbsession,
                          permission_adapter.dbsession)
        self.assertEqual(User, group_adapter.children_class)
        self.assertEquals(Group, group_adapter.parent_class,
                          permission_adapter.children_class)
        self.assertEqual(Permission, permission_adapter.parent_class)
    
    def test_with_translations(self):
        group_translations = {
            'item_name': 'member_name',
            'items': 'members'}
        permission_translations = {
            'section_name': 'authorization_name',
            'sections': 'authorizations'}
        adapters = configure_sql_adapters(User, Group, Permission, DBSession,
                                          group_translations,
                                          permission_translations)
        group_adapter = adapters['group']
        permission_adapter = adapters['permission']
        # The verifications...
        self.assertEqual(group_adapter.translations['item_name'],
                         group_translations['item_name'])
        self.assertEqual(group_adapter.translations['items'],
                         group_translations['items'])
        self.assertEqual(permission_adapter.translations['section_name'],
                         permission_translations['section_name'])
        self.assertEqual(permission_adapter.translations['sections'],
                         permission_translations['sections'])
        # Checking that the default translation is used when not overriden:
        self.assertEquals(group_adapter.translations['section_name'],
                          permission_adapter.translations['item_name'],
                          'group_name')



# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2008, Gustavo Narea <me@gustavonarea.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the BSD-like license at
# http://www.repoze.org/LICENSE.txt.  A copy of the license should accompany
# this distribution.  THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL
# EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND
# FITNESS FOR A PARTICULAR PURPOSE
#
##############################################################################

"""Stuff required to setup the test database."""

import os

from sqlalchemy import *
from sqlalchemy.orm import *
from cStringIO import StringIO
from cgi import FieldStorage

from fixture.model import init_model, DBSession, metadata, Permission, \
                          Group, User

engine = create_engine(os.environ.get('DBURL', 'sqlite://'))

def setup_database():
    init_model(engine)
    teardownDatabase()
    metadata.create_all(engine)

    # Creating permissions

    see_site = Permission()
    see_site.permission_name = u'see-site'
    DBSession.save(see_site)

    edit_site = Permission()
    edit_site.permission_name = u'edit-site'
    DBSession.save(edit_site)

    commit = Permission()
    commit.permission_name = u'commit'
    DBSession.save(commit)

    # Creating groups

    admins = Group(u'admins')
    admins.permissions.append(edit_site)
    DBSession.save(admins)

    developers = Group(u'developers')
    developers.permissions = [commit, edit_site]
    DBSession.save(developers)

    trolls = Group(u'trolls')
    trolls.permissions.append(see_site)
    DBSession.save(trolls)

    # Plus a couple of groups with no permissions
    php = Group(u'php')
    DBSession.save(php)

    python = Group(u'python')
    DBSession.save(python)

    # Creating users

    user = User()
    user.user_name = u'rms'
    user.password = u'freedom'
    user.groups.append(admins)
    user.groups.append(developers)
    DBSession.save(user)

    user = User()
    user.user_name = u'linus'
    user.password = u'linux'
    user.groups.append(developers)
    DBSession.save(user)

    user = User()
    user.user_name = u'sballmer'
    user.password = u'developers'
    user.groups.append(trolls)
    DBSession.save(user)

    # Plus a couple of users without groups
    user = User()
    user.user_name = u'guido'
    user.password = u'phytonic'
    DBSession.save(user)

    user = User()
    user.user_name = u'rasmus'
    user.password = u'php'
    DBSession.save(user)

    DBSession.commit()


def teardownDatabase():
    DBSession.rollback()
    metadata.drop_all(engine)

